﻿using FlowerShopContracts.BindingModels;
using FlowerShopContracts.BusinessLogicsContracts;
using Microsoft.Extensions.Logging;

namespace FlowerShop
{
    public partial class FormReportBouquetComponents : Form
    {
        private readonly ILogger _logger;
        private readonly IReportLogic _logic;

        public FormReportBouquetComponents(ILogger<FormReportBouquetComponents> logger, IReportLogic logic)
        {
            InitializeComponent();
            _logger = logger;
            _logic = logic;
        }

        private void FormReportBouquetComponents_Load(object sender, EventArgs e)
        {
            try
            {
                var dict = _logic.GetBouquetComponents();
                if (dict != null)
                {
                    dataGridView.Rows.Clear();
                    foreach (var elem in dict)
                    {
                        dataGridView.Rows.Add(new object[] { elem.BouquetName, "", "" });

                        foreach (var listElem in elem.Components)
                        {
                            dataGridView.Rows.Add(new object[] { "", listElem.Item1, listElem.Item2 });
                        }

                        dataGridView.Rows.Add(new object[] { "Итого", "", elem.TotalCount });
                        dataGridView.Rows.Add(Array.Empty<object>());
                    }
                }
                _logger.LogInformation("Loading list of bouquets by components");
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Error during loading list of bouquets by components");
               
                MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonSaveToExcel_Click(object sender, EventArgs e)
        {
            using var dialog = new SaveFileDialog
            {
                Filter = "xlsx|*.xlsx"
            };

            if (dialog.ShowDialog() == DialogResult.OK)
            {
                try
                {
                    _logic.SaveBouquetComponentToExcelFile(new ReportBindingModel
                    {
                        FileName = dialog.FileName
                    });

                    _logger.LogInformation("Saving list of bouquets by components");
                   
                    MessageBox.Show("Выполнено", "Успех", MessageBoxButtons.OK, MessageBoxIcon.Information);
                }
                catch (Exception ex)
                {
                    _logger.LogError(ex, "Error saving list of bouquets by components");
                   
                    MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }
    }
}
