﻿using FlowerShopContracts.BindingModels;
using FlowerShopContracts.BusinessLogicsContracts;
using Microsoft.Extensions.Logging;

namespace FlowerShop
{
    public partial class FormReportShopBouquets : Form
    {
        private readonly ILogger _logger;
        private readonly IReportLogic _logic;

        public FormReportShopBouquets(ILogger<FormReportShopBouquets> logger, IReportLogic reportLogic)
        {
            InitializeComponent();
            _logger = logger;
            _logic = reportLogic;
        }

        private void buttonSaveToExcel_Click(object sender, EventArgs e)
        {
            using var dialog = new SaveFileDialog
            {
                Filter = "xlsx|*.xlsx"
            };
            if (dialog.ShowDialog() == DialogResult.OK)
            {
                try
                {
                    _logic.SaveShopBouquetsToExcelFile(new ReportBindingModel
                    {
                        FileName = dialog.FileName
                    });
                    _logger.LogInformation("Saving list of shops with bouquets");

                    MessageBox.Show("Выполнено", "Успех", MessageBoxButtons.OK, MessageBoxIcon.Information);
                }
                catch (Exception ex)
                {
                    _logger.LogError(ex, "Error during saving list of shops with bouquets");

                    MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }

        private void FormReportShopBouquets_Load(object sender, EventArgs e)
        {
            try
            {
                var dict = _logic.GetShopBouquets();
                if (dict != null)
                {
                    dataGridView.Rows.Clear();

                    foreach (var elem in dict)
                    {
                        dataGridView.Rows.Add(new object[] { elem.ShopName, "", "" });

                        foreach (var listElem in elem.Bouquets)
                        {
                            dataGridView.Rows.Add(new object[] { "", listElem.Item1, listElem.Item2 });
                        }

                        dataGridView.Rows.Add(new object[] { "Всего:", "", elem.Count });
                        dataGridView.Rows.Add(Array.Empty<object>());
                    }
                }
                _logger.LogInformation("Loading list of shops with bouquets");
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Error during loading list of shops with bouquets");

                MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
    }
}
