using FlowerShopContracts.StoragesContracts;
using FlowerShopBusinessLogic.OfficePackage;
using FlowerShopBusinessLogic.OfficePackage.Implements;
using Microsoft.Extensions.DependencyInjection;
using FlowerShopDatabaseImplement.Implements;
using FlowerShopBusinessLogic.BusinessLogics;
using FlowerShopContracts.BusinessLogicsContracts;
using NLog.Extensions.Logging;
using Microsoft.Extensions.Logging;

namespace FlowerShop
{
    internal static class Program
    {
        private static ServiceProvider? _serviceProvider;
        public static ServiceProvider? ServiceProvider => _serviceProvider;
        
        [STAThread]
        static void Main()
        {
            ApplicationConfiguration.Initialize();
            var services = new ServiceCollection();
            ConfigureServices(services);
            _serviceProvider = services.BuildServiceProvider();
            Application.Run(_serviceProvider.GetRequiredService<FormMain>());
        }
        private static void ConfigureServices(ServiceCollection services)
        {
            services.AddLogging(option =>
            {
                option.SetMinimumLevel(LogLevel.Information);
                option.AddNLog("nlog.config");
            });
            services.AddTransient<IComponentStorage, ComponentStorage>();
            services.AddTransient<IOrderStorage, OrderStorage>();
            services.AddTransient<IBouquetStorage, BouquetStorage>();
            services.AddTransient<IShopStorage, ShopStorage>();

            services.AddTransient<IComponentLogic, ComponentLogic>();
            services.AddTransient<IOrderLogic, OrderLogic>();
            services.AddTransient<IBouquetLogic, BouquetLogic>();
            services.AddTransient<IReportLogic, ReportLogic>();
            services.AddTransient<IShopLogic, ShopLogic>();

            services.AddTransient<AbstractSaveToWord, SaveToWord>();
            services.AddTransient<AbstractSaveToExcel, SaveToExcel>();
            services.AddTransient<AbstractSaveToPdf, SaveToPdf>();

            services.AddTransient<FormMain>();
            services.AddTransient<FormComponent>();
            services.AddTransient<FormComponents>();
            services.AddTransient<FormCreateOrder>();
            services.AddTransient<FormBouquet>();
            services.AddTransient<FormBouquets>();
            services.AddTransient<FormBouquetComponent>();
            services.AddTransient<FormShop>();
            services.AddTransient<FormShops>();
            services.AddTransient<FormShopSupply>();
            services.AddTransient<FormShopSell>();
            services.AddTransient<FormReportBouquetComponents>();
            services.AddTransient<FormReportOrder>();
            services.AddTransient<FormReportShopBouquets>();
            services.AddTransient<FormReportDateOrders>();
        }
    }
}