﻿using FlowerShopBusinessLogic.OfficePackage.HelperEnums;
using FlowerShopBusinessLogic.OfficePackage.HelperModels;

namespace FlowerShopBusinessLogic.OfficePackage
{
    public abstract class AbstractSaveToWord
    {
        public void CreateDoc(WordInfo info)
        {
            CreateWord(info);

            CreateParagraph(new WordParagraph
            {
                Texts = new List<(string, WordTextProperties)> { (info.Title, new WordTextProperties { Bold = true, Size = "24", }) },
                TextProperties = new WordTextProperties
                {
                    Size = "24",
                    JustificationType = WordJustificationType.Center
                }
            });

            foreach (var bouquet in info.Bouquets)
            {
                CreateParagraph(new WordParagraph
                {
                    Texts = new List<(string, WordTextProperties)>
                    {(bouquet.BouquetName + " - ", new WordTextProperties { Size = "24", Bold = true}),
                     (bouquet.Price.ToString(), new WordTextProperties { Size = "24", })},

                    TextProperties = new WordTextProperties
                    {
                        Size = "24",
                        JustificationType = WordJustificationType.Both
                    }
                });
            }
            SaveWord(info);
        }

        public void CreateTableDoc(WordInfo wordInfo)
        {
            CreateWord(wordInfo);

            var list = new List<string>();
            foreach (var shop in wordInfo.Shops)
            {
                list.Add(shop.Name);
                list.Add(shop.Address);
                list.Add(shop.OpeningDate.ToString());
            }

            var wordTable = new WordTable
            {
                Headers = new List<string> {
                    "Название",
                    "Адрес",
                    "Дата открытия"},
                Texts = list
            };

            CreateTable(wordTable);

            SaveWord(wordInfo);
        }

        protected abstract void CreateWord(WordInfo info);

        protected abstract void CreateParagraph(WordParagraph paragraph);

        protected abstract void SaveWord(WordInfo info);

        protected abstract void CreateTable(WordTable info);
    }
}
